@@ -69,8 +69,18 @@ def prompt_bool(name, default=False, yes_choices=None, no_choices=None):
     yes_choices = yes_choices or ('y', 'yes', '1', 'on', 'true', 't')
     no_choices = no_choices or ('n', 'no', '0', 'off', 'false', 'f')
 
+    if default is None:
+        prompt_choice = 'y/n'
+    elif default is True:
+        prompt_choice = 'Y/n'
+    else:
+        prompt_choice = 'y/N'
+
+    prompt = name + ' [%s]' % prompt_choice
+    prompt += name.endswith('?') and ' ' or ': '
+
     while True:
-        rv = prompt(name, default and yes_choices[0] or no_choices[0])
+        rv = input(prompt)
         if not rv:
             return default
         if rv.lower() in yes_choices:
@@ -79,6 +89,9 @@ def prompt_bool(name, default=False, yes_choices=None, no_choices=None):
             return False
 
 
+def prompt_yes_no(name, default=True):
+    return prompt_bool(name, default=default)
+
 def prompt_choices(name, choices, default=None, resolve=ascii_lowercase,
                    no_choice=('none',)):
     """
@@ -115,7 +128,9 @@ def prompt_choices(name, choices, default=None, resolve=ascii_lowercase,
             return rv
 
 
-class ConfigCompleter(argcomplete.completers.FilesCompleter):
+class ConfigFileCompleter(argcomplete.completers.FilesCompleter):
+
+    """ argcomplete completer for tmuxp files. """
 
     def __call__(self, prefix, **kwargs):
         completion = argcomplete.completers.FilesCompleter.__call__(
@@ -130,6 +145,8 @@ class ConfigCompleter(argcomplete.completers.FilesCompleter):
 
 class TmuxinatorCompleter(argcomplete.completers.FilesCompleter):
 
+    """ argcomplete completer for Tmuxinator files. """
+
     def __call__(self, prefix, **kwargs):
         completion = argcomplete.completers.FilesCompleter.__call__(
             self, prefix, **kwargs
@@ -145,6 +162,8 @@ class TmuxinatorCompleter(argcomplete.completers.FilesCompleter):
 
 class TeamocilCompleter(argcomplete.completers.FilesCompleter):
 
+    """ argcomplete completer for Teamocil files. """
+
     def __call__(self, prefix, **kwargs):
         completion = argcomplete.completers.FilesCompleter.__call__(
             self, prefix, **kwargs
@@ -158,16 +177,19 @@ class TeamocilCompleter(argcomplete.completers.FilesCompleter):
 
 
 def SessionCompleter(prefix, **kwargs):
+    """ Return list of session names for argcomplete completer. """
     t = Server()
-    return [s.get('session_name') for s in t._sessions if s.get('session_name').startswith(prefix)]
+    return [s.get('session_name') for s in t._sessions
+            if s.get('session_name').startswith(prefix)]
 
 
 def setupLogger(logger=None, level='INFO'):
-    '''setup logging for CLI use.
+    """Setup logging for CLI use.
 
     :param logger: instance of logger
     :type logger: :py:class:`Logger`
-    '''
+
+    """
     if not logger:
         logger = logging.getLogger()
     if not logger.handlers:
@@ -178,22 +200,24 @@ def setupLogger(logger=None, level='INFO'):
 
 
 def startup(config_dir):
-    ''' Initialize CLI.
+    """Initialize CLI.
 
     :param config_dir: Config directory to search
     :type config_dir: string
-    '''
+
+    """
 
     if not os.path.exists(config_dir):
         os.makedirs(config_dir)
 
 
-def build_workspace(config_file, args):
-    ''' build config workspace.
+def load_workspace(config_file, args):
+    """ Build config workspace.
 
     :param config_file: full path to config file
     :param type: string
-    '''
+
+    """
     logger.info('building %s.' % config_file)
 
     sconfig = kaptan.Kaptan()
@@ -218,7 +242,7 @@ def build_workspace(config_file, args):
         builder.build()
 
         if 'TMUX' in os.environ:
-            if prompt_bool('Already inside TMUX, load session?'):
+            if prompt_yes_no('Already inside TMUX, load session?'):
                 del os.environ['TMUX']
                 os.execl(tmux_bin, 'tmux', 'switch-client', '-t', sconfig[
                          'session_name'])
@@ -226,7 +250,7 @@ def build_workspace(config_file, args):
         os.execl(tmux_bin, 'tmux', 'attach-session', '-t', sconfig[
                  'session_name'])
     except exc.TmuxSessionExists as e:
-        attach_session = prompt_bool(e.message + ' Attach?')
+        attach_session = prompt_yes_no(e.message + ' Attach?')
 
         if 'TMUX' in os.environ:
             del os.environ['TMUX']
@@ -239,7 +263,8 @@ def build_workspace(config_file, args):
         return
 
 
-def subcommand_load(args):
+def command_load(args):
+    """ Load a session from a tmuxp session file. """
     if args.list:
         startup(config_dir)
         configs_in_user = config.in_dir(config_dir)
@@ -272,14 +297,16 @@ def subcommand_load(args):
         file_user = os.path.join(config_dir, configfile)
         file_cwd = os.path.join(cwd_dir, configfile)
         if os.path.exists(file_cwd) and os.path.isfile(file_cwd):
-            build_workspace(file_cwd, args)
+            load_workspace(file_cwd, args)
         elif os.path.exists(file_user) and os.path.isfile(file_user):
-            build_workspace(file_user, args)
+            load_workspace(file_user, args)
         else:
             logger.error('%s not found.' % configfile)
 
 
-def subcommand_import_teamocil(args):
+def command_import_teamocil(args):
+    """ Import teamocil config to tmuxp format. """
+
     if args.list:
             try:
                 configs_in_user = config.in_dir(
@@ -306,8 +333,7 @@ def subcommand_import_teamocil(args):
                 )
 
             print(output)
-
-    if args.config:
+    elif args.config:
         configfile = os.path.relpath(args.config)
         configparser = kaptan.Kaptan(handler='yaml')
         configparser.import_config(configfile)
@@ -322,7 +348,8 @@ def subcommand_import_teamocil(args):
         print(newconfig)
 
 
-def subcommand_import_tmuxinator(args):
+def command_import_tmuxinator(args):
+    """ Import tmuxinator config to tmuxp format. """
     if args.list:
             try:
                 configs_in_user = config.in_dir(
@@ -365,7 +392,8 @@ def subcommand_import_tmuxinator(args):
         print(newconfig)
 
 
-def subcommand_convert(args):
+def command_convert(args):
+    """ Convert tmuxp config to and from JSON and YAML. """
 
     try:
         configfile = args.config
@@ -386,33 +414,34 @@ def subcommand_convert(args):
         return
 
     if 'json' in ext:
-        if prompt_bool('convert to <%s> to yaml?' % (fullfile)):
+        if prompt_yes_no('convert to <%s> to yaml?' % (fullfile)):
             configparser = kaptan.Kaptan()
             configparser.import_config(configfile)
             newfile = fullfile.replace(ext, '.yaml')
             newconfig = configparser.export(
                 'yaml', indent=2, default_flow_style=False
             )
-            if prompt_bool('write config to %s?' % (newfile)):
+            if prompt_yes_no('write config to %s?' % (newfile)):
                 buf = open(newfile, 'w')
                 buf.write(newconfig)
                 buf.close()
                 print('written new config to %s' % (newfile))
     elif 'yaml' in ext:
-        if prompt_bool('convert to <%s> to json?' % (fullfile)):
+        if prompt_yes_no('convert to <%s> to json?' % (fullfile)):
             configparser = kaptan.Kaptan()
             configparser.import_config(configfile)
             newfile = fullfile.replace(ext, '.json')
             newconfig = configparser.export('json', indent=2)
             print(newconfig)
-            if prompt_bool('write config to <%s>?' % (newfile)):
+            if prompt_yes_no('write config to <%s>?' % (newfile)):
                 buf = open(newfile, 'w')
                 buf.write(newconfig)
                 buf.close()
                 print('written new config to <%s>.' % (newfile))
 
 
-def subcommand_attach_session(args):
+def command_attach_session(args):
+    """ Command to attach / switch client to a tmux session."""
     commands = []
     ctext = args.session_name
 
@@ -438,7 +467,8 @@ def subcommand_attach_session(args):
         print('Attaching client.')
 
 
-def subcommand_kill_session(args):
+def command_kill_session(args):
+    """ Command to kill a tmux session."""
     commands = []
     ctext = args.session_name
 
@@ -462,7 +492,8 @@ def subcommand_kill_session(args):
         logger.error(e)
 
 
-def cli_parser():
+def get_parser():
+    """ Return :py:class:`argparse.ArgumentParser` instance for CLI. """
 
     parser = argparse.ArgumentParser(
         description='''\
@@ -470,12 +501,12 @@ def cli_parser():
         ''',
     )
 
-    subparsers = parser.add_subparsers(title='subcommands',
-                                       description='valid subcommands',
+    subparsers = parser.add_subparsers(title='commands',
+                                       description='valid commands',
                                        help='additional help')
 
     kill_session = subparsers.add_parser('kill-session')
-    kill_session.set_defaults(callback=subcommand_kill_session)
+    kill_session.set_defaults(callback=command_kill_session)
 
     kill_session.add_argument(
         dest='session_name',
@@ -484,7 +515,7 @@ def cli_parser():
     ).completer = SessionCompleter
 
     attach_session = subparsers.add_parser('attach-session')
-    attach_session.set_defaults(callback=subcommand_attach_session)
+    attach_session.set_defaults(callback=command_attach_session)
 
     attach_session.add_argument(
         dest='session_name',
@@ -513,8 +544,8 @@ def cli_parser():
         will check launch a ~/.pullv.yaml / ~/.pullv.json from the cwd.
         will also check for any ./*.yaml and ./*.json.
         ''' % (cwd_dir + '/', config_dir),
-    ).completer = ConfigCompleter(allowednames=('.yaml', '.json'), directories=False)
-    load.set_defaults(callback=subcommand_load)
+    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
+    load.set_defaults(callback=command_load)
 
     convert = subparsers.add_parser('convert')
 
@@ -530,13 +561,13 @@ def cli_parser():
         will check launch a ~/.pullv.yaml / ~/.pullv.json from the cwd.
         will also check for any ./*.yaml and ./*.json.
         ''' % (cwd_dir + '/', config_dir)
-    ).completer = ConfigCompleter(allowednames=('.yaml', '.json'), directories=False)
+    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
 
-    convert.set_defaults(callback=subcommand_convert)
+    convert.set_defaults(callback=command_convert)
 
     importparser = subparsers.add_parser('import')
-    importsubparser = importparser.add_subparsers(title='subcommands',
-                                                  description='valid subcommands',
+    importsubparser = importparser.add_subparsers(title='commands',
+                                                  description='valid commands',
                                                   help='additional help')
 
     import_teamocil = importsubparser.add_parser('teamocil')
@@ -556,7 +587,7 @@ def cli_parser():
         Checks current ~/.teamocil and current directory for yaml files.
         '''
     ).completer = TeamocilCompleter(allowednames=('.yml'), directories=False)
-    import_teamocil.set_defaults(callback=subcommand_import_teamocil)
+    import_teamocil.set_defaults(callback=command_import_teamocil)
 
     import_tmuxinator = importsubparser.add_parser('tmuxinator')
 
@@ -576,7 +607,7 @@ def cli_parser():
         '''
     ).completer = TmuxinatorCompleter(allowednames=('.yml'), directories=False)
 
-    import_tmuxinator.set_defaults(callback=subcommand_import_tmuxinator)
+    import_tmuxinator.set_defaults(callback=command_import_tmuxinator)
 
     parser.add_argument('--log-level', dest='log_level', default='INFO',
                         metavar='log-level',
@@ -599,7 +630,7 @@ def cli_parser():
 
 def main():
 
-    parser = cli_parser()
+    parser = get_parser()
 
     argcomplete.autocomplete(parser, always_complete_options=False)
 
@@ -615,17 +646,17 @@ def main():
 
     util.oh_my_zsh_auto_title()
 
-    if args.callback is subcommand_load:
-        subcommand_load(args)
-    elif args.callback is subcommand_convert:
-        subcommand_convert(args)
-    elif args.callback is subcommand_import_teamocil:
-        subcommand_import_teamocil(args)
-    elif args.callback is subcommand_import_tmuxinator:
-        subcommand_import_tmuxinator(args)
-    elif args.callback is subcommand_attach_session:
-        subcommand_attach_session(args)
-    elif args.callback is subcommand_kill_session:
-        subcommand_kill_session(args)
+    if args.callback is command_load:
+        command_load(args)
+    elif args.callback is command_convert:
+        command_convert(args)
+    elif args.callback is command_import_teamocil:
+        command_import_teamocil(args)
+    elif args.callback is command_import_tmuxinator:
+        command_import_tmuxinator(args)
+    elif args.callback is command_attach_session:
+        command_attach_session(args)
+    elif args.callback is command_kill_session:
+        command_kill_session(args)
     else:
         parser.print_help()
